%%%%%%%%
%%% CALIBRATION FOR BULGARIA
%%%%%%%%
close all; clear all;

%% Reads the model
[m,p,mss] = readmodel(true);

%% Variances
p.std_shk_lgdp_gap = 1;
p.std_shk_dot_cpi = 1;
p.std_shk_ls = 1;
p.std_shk_rn = 1;
p.std_shk_dot_s_tar = 1;
p.std_shk_target = 1;
p.std_shk_rr_eq = 1;
p.std_shk_dot_z_eq = 1;
p.std_shk_dot_gdp_eq = 1;
p.std_shk_x_rn = 1;
p.std_shk_dot_x_cpi = 1;
p.std_shk_x_rr_eq = 1;

%% Adds variances to the model
m = assign(m,p);
m = solve(m);

%% Data sample
sdate = qq(1999,1);
edate = qq(2010,1);

%% Data transformation and filtration
d = loadstruct('history.mat');

dd.L_CPI = d.lcpi;
dd.RN = d.rn;
dd.L_S = d.ls;
dd.L_GDP = d.lgdp;
dd.L_X_CPI = d.lx_cpi;
dd.X_RN = d.x_rn;

data = db2dpack(m, dd, sdate:edate);
[mlog, se2, pred, smooth] = kalmanf(m, data);

d = dp2dbase(smooth.mean);

%% Save the database
% Database is saved in file 'kalm_his.mat'
savestruct('kalm_his.mat',d);
dbsave(d,'kalm_his.csv');

%% Graphs
Plotrng = sdate:edate;

Heading = 'Bulgaria - Kalman filter estimates';

x = report('heading',Heading,'dateformat','YYYY:P','color', true);

x = newpage(x);

x = opengraph(x);

  x = tag(x,'Trends','fontsize','large');

  subplot(3,2,1);
  plot(Plotrng,d.lgdp,'b');
  hold on
  plot(Plotrng,d.lgdp_eq,'r');
  title('Output'); 
  grid on; box off;
  
  subplot(3,2,2);
  plot(Plotrng,d.rr,'b');
  hold on
  plot(Plotrng,d.rr_eq,'r');
  title('Real Interest Rate'); 
  grid on; box off;
  
  subplot(3,2,3);
  plot(Plotrng,d.lz,'b');
  hold on
  plot(Plotrng,d.lz_eq,'r');
  title('Real Exchange Rate'); 
  grid on; box off;
  
  subplot(3,2,4);
  plot(Plotrng,d.x_rr,'b');
  hold on
  plot(Plotrng,d.x_rr_eq,'r');
  title('Foreign Real Interest Rate'); 
  grid on; box off;
  
  subplot(3,2,5);
  plot(Plotrng,d.dot_z_eq,'r');
  title('Eq. Real Exchange Rate Path (- = appreciation)'); 
  grid on; box off;

  subplot(3,2,6);
  plot(Plotrng,d.prem,'r');
  title('Risk Premium'); 
  grid on; box off;

x = getgraph(x);

x = newpage(x);

x = opengraph(x);

  x = tag(x,'Gaps','fontsize','large');

  subplot(2,3,1);
  plot(Plotrng,d.dot_cpi);
  title('Inflation'); 
  grid on; box off;
  
  subplot(2,3,2);
  plot(Plotrng,d.rmc);
  title('Real Marginal Cost Gap'); 
  grid on; box off;
  
  subplot(2,3,3);
  plot(Plotrng,d.lgdp_gap);
  title('Output Gap'); 
  grid on; box off;
  
  subplot(2,3,4);
  plot(Plotrng,d.lz_gap);
  title('Real Exchange Rate Gap'); 
  grid on; box off;
  
  subplot(2,3,5);
  plot(Plotrng,d.rr_gap);
  title('Real Interest Rate Gap'); 
  grid on; box off;
  
  subplot(2,3,6);
  plot(Plotrng,d.mci);
  title('Real Monetary Conditions'); 
  grid on; box off;
  
x = getgraph(x);

%% Saves all graphs
%% The default is set to generate both .ps and .pdf files:
compile(x,'Filter.ps','display',false);
compile(x,'Filter.pdf','display',false);